# Guidance on Accessibility

> _The power of the Web is in its universality. Access by everyone regardless of disability is an essential aspect._<br>
**Tim Berners-Lee, W3C Director and inventor of the World Wide Web**

Accessibility regulations have been implemented for all public sectors and government bodies since [23 September 2018](https://www.gov.uk/guidance/accessibility-requirements-for-public-sector-websites-and-apps). These regulations set the direction that all government websites and apps are required to be "perceivable, operable, understandable and robust".

> **See the [NHS "digital service manual"](https://service-manual.nhs.uk/accessibility) on accessibility and why it matters**.

We follow suit at NHS Digital, building up on government accessibility directives, releasing and maintaining a wide range of NHS services and products, encompassing accessibility standards in each project development's phase:
* **product and delivery:** including the questions product or delivery managers need to be asking.
* **user research:** from identifying target groups and accessibility challenges to including users with access needs in research and practicalities like making your research sessions more accessible on the day.
* **content:** how to write effective, clear content as well as headings, good link names, handling images in content and making multimedia accessible.
* **design:** it includes, for example, colour contrast, designing new components (only after you've tested existing ones) and handling errors in forms.
* **development**, including information on how to make your service accessible for those who can’t use a mouse or trackpad and rely on keyboards or joysticks.
* **testing:** different kinds of testing (user research, manual and automated) and the wide range of things that may need checking.

> **Find out more on how NHS Digital works on [making digital services accessible](https://digital.nhs.uk/blog/transformation-blog/2019/making-digital-services-accessible)**.

## Accessibility and RAP: end user
For the purposes of RAP publications it's important to consider the end user, and how accessible are the design outputs, graphs and charts, documentation and user guidance catering to all audiences and adhering to accessibility standards. Both the government and NHS have released a variety of accessiblity service manuals and posters to support development and design teams on improving services and product accessibility requirements:

#### GSS accessibility standards for publications
* [Government Analysis Function - Making analytical publications accessible](https://analysisfunction.civilservice.gov.uk/policy-store/making-analytical-publications-accessible/)
#### Government accessibility standards
* [Gov.uk - Understanding accessibility requirements for public sector bodies](https://www.gov.uk/guidance/accessibility-requirements-for-public-sector-websites-and-apps)
#### Posters
* [Home Office accessibility posters](https://github.com/UKHomeOffice/posters/blob/master/accessibility/dos-donts/posters_en-UK/accessibility-posters-set.pdf)
* [NHS digital service manual accessibility posters](https://service-manual.nhs.uk/accessibility/download-accessibility-posters)

## Accessibility and RAP: analyst
As more and more NHS Digiital RAP pipelines are being published on GitHub, RAP analysts and developers need to consider documentation and user guidance adhering to accessibility practices includes the RAP pipeline itself (e.g. every user can run the pipeline without any hindrances), the public facing repository and its contents, repository documentation (e.g. README, CONTRIBUTING, CODE OF CONDUCT etc.) and other pipeline documentation.

#### Documentation, page structure design, development and testing
* [NHS digital service manual (DSM): content](https://service-manual.nhs.uk/accessibility/content)
* [NHS DSM: design](https://service-manual.nhs.uk/accessibility/design)
* [NHS DSM: developmemt](https://service-manual.nhs.uk/accessibility/development)
* [NHS DSM: testing](https://service-manual.nhs.uk/accessibility/testing)

#### To further cater to all user requirements, here are a few tips on making your repositories more inclusive
* [NHSD Software Engineering practices and recommendations on inclusive language](https://github.com/NHSDigital/software-engineering-quality-framework/blob/main/inclusive-language.md)
