# Why RAP is important

Scientific research has increasingly relied on code to conduct complex statistical analyses in recent years. As code has become ubiquitous, new ways of working have emerged to ensure that scientific findings are rigorous and reproducible.

These practices have been applied to government analytic work under the banner of **Reproducible Analytical Pipelines (RAP)**. RAPs bring together a number of good practices to help ensure all published statistics meet the highest standards of transparency and reproducibility.

Over time, all analytical work in NHS Digital (and across government) will be expected to adopt the RAP practices. For example, RAP practices are a key element needed in order to meet the standards of quality analysis set out in the [Aqua Book](https://www.gov.uk/government/publications/the-aqua-book-guidance-on-producing-quality-analysis-for-government) guidelines, which revolve around analysis being reproducible, auditable, transparent, and quality assured. This adoption will take time and should not be considered as all-or-nothing. There are stages to RAP. Teams can take the journey one step at a time with support from this community.

## The benefits of RAP at NHS Digital

The NHS Digital [mission statement](https://digital.nhs.uk/about-nhs-digital/corporate-information-and-documents/our-strategy) says:

> Our goal is to maximise the accessibility, quality and utility of health and care data while respecting privacy, transparency and ethics.

This goal aligns closely with the three main benefits of reproducible research from a scientific perspective [Alston and Rick, 2021](https://esajournals.onlinelibrary.wiley.com/doi/full/10.1002/bes2.1801):

> 1. "Reproducible research allows others to learn from your work. Scientific research has a steep learning curve, and allowing others to access data and code gives them a head start on performing similar analyses."
> 2. "Reproducible research allows others to understand and reproduce a researcher's work."
> 3. "Reproducible research allows others to protect themselves from your mistakes."

RAP therefore helps us to:

- Improve the transparency and ethics by showing our workings and giving users a way to feed back into our processes.
- Improve the accessibility of data by outputting data in a consistent, predictable, and accessible format for users.
- Improve the quality of data by ensuring good coding standards are applied.
- Improve the utility of data by sharing code. This shows users how the data have been produced and allowing them to reuse our code.
- Improve the reliability of data by automating manual steps where possible.

## Aims of RAP

This community of practice aims to support teams in adopting RAP practices through:

1. **Developing learning materials including reusable templates:**
   Most of the learning materials were initially adapted for the NHS Digital analytical environment, but most are applicable elsewhere.
2. **Offering support as teams establish new working practices:**
   We offer in-person support to NHS Digital teams in the form of bespoke coaching sessions. We also co-ordinate informal weekly drop-in sessions (internal to NHS Digital) and host monthly workshops, where you can learn from others at different stages of RAP adoption, and get advice. If you would like to attend these please [contact us](mailto:datascience@nhs.net).

This work is prompted by the observations that teams can struggle to adopt RAP practices without support. While no one element of RAP is particularly difficult, learning several new skills at the same time as delivering BAU is challenging. Teams can struggle to protect time to embed these practices. (The Statistics Authority report on [the barriers to RAP adoption](https://osr.statisticsauthority.gov.uk/publication/reproducible-analytical-pipelines-overcoming-barriers-to-adoption/) is an excellent discussion of the challenges in rolling out RAP).

Luckily, at NHS Digital we have strong senior support for RAP and several teams have already begun to adopt many of the practices included in RAP. Consequently, we already have a large pool of skilled, enthusiastic analysts who are willing to help others. These resources also aim to support the goals laid out in the Goldacre report [Bringing NHS data analysis into the 21st century](https://journals.sagepub.com/doi/10.1177/0141076820930666) and to align with Tim Berners-Lee's [five star data](https://5stardata.info/en/) principles. Over time we hope to build up a community of people who can self-support and further develop these ways of working.
